@@ -1,7 +1,7 @@
 package App::depak;
 
-our $DATE = '2015-07-07'; # DATE
-our $VERSION = '0.43'; # VERSION
+our $DATE = '2015-07-27'; # DATE
+our $VERSION = '0.44'; # VERSION
 
 use 5.010001;
 use strict;
@@ -724,7 +724,7 @@ _
 
         debug_keep_tempdir => {
             summary => 'Keep temporary directory for debugging',
-            schema => ['bool' => default=>0],
+            schema => ['bool'],
             tags => ['category:debugging'],
         },
 
@@ -765,6 +765,8 @@ sub depak {
     my %args = @_;
     my $self = __PACKAGE__->new(%args);
 
+    $self->{debug_keep_tempdir} //= $ENV{DEBUG_KEEP_TEMPDIR} // 0;
+
     my $tempdir = File::Temp::tempdir(CLEANUP => 0);
     $log->debugf("Created tempdir %s", $tempdir);
     $self->{tempdir} = $tempdir;
@@ -951,7 +953,7 @@ App::depak - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.43 of App::depak (from Perl distribution App-depak), released on 2015-07-07.
+This document describes version 0.44 of App::depak (from Perl distribution App-depak), released on 2015-07-27.
 
 =head1 SYNOPSIS
 
@@ -964,7 +966,7 @@ See L<depak>.
 
 =head2 depak(%args) -> [status, msg, result, meta]
 
-Pack your dependencies onto your script file.
+{en_US Pack your dependencies onto your script file}.
 
 Arguments ('*' denotes required arguments):
 
@@ -974,8 +976,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<args> => I<array[str]>
 
-Script arguments.
+{en_US Script arguments}.
 
+{en_US 
 Will be used when running your script, e.g. when C<trace_method> is C<fatpacker>
 or C<require>. For example, if your script requires three arguments: C<--foo>,
 C<2>, C<"bar baz"> then you can either use:
@@ -986,40 +989,49 @@ or:
 
  % depak script output --args-json '["--foo",2,"bar baz"]'
 
-=item * B<debug_keep_tempdir> => I<bool> (default: 0)
+}
 
-Keep temporary directory for debugging.
+=item * B<debug_keep_tempdir> => I<bool>
+
+{en_US Keep temporary directory for debugging}.
 
 =item * B<exclude> => I<array[str]>
 
-Modules to exclude.
+{en_US Modules to exclude}.
 
+{en_US 
 When you don't want to include a module, specify it here.
+}
 
 =item * B<exclude_core> => I<bool> (default: 1)
 
-Whether to exclude core modules.
+{en_US Whether to exclude core modules}.
 
 =item * B<exclude_dist> => I<array[str]>
 
-Exclude all modules of dist.
+{en_US Exclude all modules of dist}.
 
+{en_US 
 Just like the C<exclude> option, but will exclude module as well as other modules
 from the same distribution. Module name must be the main module of the
 distribution. Will determine other modules from the C<.packlist> file.
+}
 
 =item * B<exclude_list> => I<str>
 
-Exclude modules from a list in a file.
+{en_US Exclude modules from a list in a file}.
 
 =item * B<exclude_pattern> => I<array[str]>
 
-Regex patterns of modules to exclude.
+{en_US Regex patterns of modules to exclude}.
 
+{en_US 
 When you don't want to include a pattern of modules, specify it here.
+}
 
 =item * B<exclude_prereq> => I<array[str]>
 
+{en_US 
 This option can be used to express that script will depend on a specified
 module, instead of including it packed. The prereq-ed module, as well as other
 modules in the same distribution, as well as its prereqs and so on recursively,
@@ -1031,32 +1043,38 @@ cannot be packed.
 To query dependencies, a local CPAN index is used for querying speed. Thus, this
 option requires that C<lcpan> is installed and a fairly recent lcpan index is
 available.
+}
 
 =item * B<include> => I<array[str]>
 
-Include extra modules.
+{en_US Include extra modules}.
 
+{en_US 
 When the tracing process fails to include a required module, you can add it
 here.
+}
 
 =item * B<include_dir> => I<array[str]>
 
-Include extra modules under directories.
+{en_US Include extra modules under directories}.
 
 =item * B<include_dist> => I<array[str]>
 
-Include all modules of dist.
+{en_US Include all modules of dist}.
 
+{en_US 
 Just like the C<include> option, but will include module as well as other modules
 from the same distribution. Module name must be the main module of the
 distribution. Will determine other modules from the C<.packlist> file.
+}
 
 =item * B<include_list> => I<str>
 
-Include extra modules from a list in a file.
+{en_US Include extra modules from a list in a file}.
 
 =item * B<include_prereq> => I<array[str]>
 
+{en_US 
 This option can be used to include a module, as well as other modules in the
 same distribution as that module, as well as the distribution's recursive
 dependencies, for packing. Dependencies will be searched using a local CPAN
@@ -1065,32 +1083,38 @@ to use this option together with setting C<trace_method> to C<none>.
 
 This option requires that C<lcpan> is installed and a fairly recent lcpan index
 is available.
+}
 
 =item * B<input_file> => I<str> (default: "-")
 
-Path to input file (script to be packed).
+{en_US Path to input file (script to be packed)}.
 
+{en_US 
 C<-> (or if unspecified) means to take from standard input (internally, a
 temporary file will be created to handle this).
+}
 
 =item * B<multiple_runs> => I<array[hash]>
 
-Pass to tracepm.
+{en_US Pass to tracepm}.
 
 =item * B<output_file> => I<str> (default: "-")
 
-Path to output file.
+{en_US Path to output file}.
 
+{en_US 
 C<-> (or if unspecified) means to output to stdout.
+}
 
 =item * B<overwrite> => I<bool> (default: 0)
 
-Whether to overwrite output if previously exists.
+{en_US Whether to overwrite output if previously exists}.
 
 =item * B<pack_method> => I<str> (default: "fatpack")
 
-Packing method to use.
+{en_US Packing method to use}.
 
+{en_US 
 Either C<fatpack> (the default) or C<datapack>. Fatpack puts packed modules inside
 Perl variables and load them via require hook. Datapack puts packed modules in
 B<DATA> section. For more details about each method, please consult
@@ -1100,82 +1124,93 @@ One thing to remember is, with datapack, your script cannot load modules during
 compile-time (C<use>): all modules must be loaded during run-time (C<require>)
 when data section is already available. Also, your script currently cannot
 contain data section of its own.
+}
 
 =item * B<perl_version> => I<str>
 
-Perl version to target, defaults to current running version.
+{en_US Perl version to target, defaults to current running version}.
 
+{en_US 
 This is for determining which modules are considered core and should be skipped
 by default (when C<exclude_core> option is enabled). Different perl versions have
 different sets of core modules as well as different versions of the modules.
+}
 
 =item * B<shebang> => I<str> (default: "/usr/bin/perl")
 
-Set shebang line/path.
+{en_US Set shebang line/path}.
 
 =item * B<skip_not_found> => I<bool> (default: 1)
 
-Instead of dying, skip when module to add is not found.
+{en_US Instead of dying, skip when module to add is not found}.
 
+{en_US 
 This option is useful when you use C<include_prereq>, because modules without its
 own .pm files will also be included (CPAN indexes packages, including those that
 do not have their own .pm files).
+}
 
 =item * B<squish> => I<bool> (default: 0)
 
-Whether to squish included modules using Perl::Squish.
+{en_US Whether to squish included modules using Perl::Squish}.
 
 =item * B<strip> => I<bool> (default: 0)
 
-Whether to strip included modules using Perl::Strip.
+{en_US Whether to strip included modules using Perl::Strip}.
 
 =item * B<stripper> => I<bool> (default: 0)
 
-Whether to strip included modules using Perl::Stripper.
+{en_US Whether to strip included modules using Perl::Stripper}.
 
 =item * B<stripper_comment> => I<bool> (default: 1)
 
-Set strip_comment=1 (strip comments) in Perl::Stripper.
+{en_US Set strip_comment=1 (strip comments) in Perl::Stripper}.
 
 =item * B<stripper_log> => I<bool> (default: 0)
 
-Set strip_log=1 (strip log statements) in Perl::Stripper.
+{en_US Set strip_log=1 (strip log statements) in Perl::Stripper}.
 
 =item * B<stripper_maintain_linum> => I<bool> (default: 0)
 
-Set maintain_linum=1 in Perl::Stripper.
+{en_US Set maintain_linum=1 in Perl::Stripper}.
 
 =item * B<stripper_pod> => I<bool> (default: 1)
 
-Set strip_pod=1 (strip POD) in Perl::Stripper.
+{en_US Set strip_pod=1 (strip POD) in Perl::Stripper}.
 
 =item * B<stripper_ws> => I<bool> (default: 1)
 
-Set strip_ws=1 (strip whitespace) in Perl::Stripper.
+{en_US Set strip_ws=1 (strip whitespace) in Perl::Stripper}.
 
 =item * B<test> => I<bool>
 
-Test the resulting output.
+{en_US Test the resulting output}.
 
+{en_US 
 Testing is done by running the resulting packed script with perl. To test, at
 least one test case is required (see C<--test-case-json>). Test cases specify
 what arguments to give to program, what exit code we expect, and what the output
 should contain.
+}
 
 =item * B<test_cases> => I<array[hash]>
 
+{en_US 
 Example case:
 
  {"args":["--help"], "exit_code":0, "perl_args":["-Mlib::core::only"], "output_like":"Usage:"}
 
+}
+
 =item * B<trace_extra_opts> => I<hash>
 
-Pass more options to `App::tracepm`.
+{en_US Pass more options to `App::tracepm`}.
 
 =item * B<trace_method> => I<str> (default: "fatpacker")
 
-Which method to use to trace dependencies.
+{en_US Which method to use to trace dependencies}.
 
+{en_US 
 The default is C<fatpacker>, which is the same as what C<fatpack trace> does.
 Different tracing methods have different pro's and con's, one method might
 detect required modules that another method does not, and vice versa. There are
@@ -1183,13 +1218,16 @@ several methods available, please see C<App::tracepm> for more details.
 
 A special value of C<none> is also provided. If this is selected, then depak will
 not perform any tracing. Usually used in conjunction with C<--include-from>.
+}
 
 =item * B<use> => I<array[str]>
 
-Additional modules to "use".
+{en_US Additional modules to "use"}.
 
+{en_US 
 Will be passed to the tracer. Will currently only affect the C<fatpacker> and
 C<require> methods (because those methods actually run your script).
+}
 
 =back
 
